pub struct StructEnumVisitor<'tcx> {
pub structs: HashMap<DefId, StructInfo>,
pub enums: HashMap<DefId, EnumInfo>,
/* private fields */
}Fields
structs: HashMap<DefId, StructInfo>enums: HashMap<DefId, EnumInfo>Trait Implementations
Sourceimpl Debug for StructEnumVisitor<'_>
impl Debug for StructEnumVisitor<'_>
Sourceimpl<'tcx> Visitor<'tcx> for StructEnumVisitor<'tcx>
impl<'tcx> Visitor<'tcx> for StructEnumVisitor<'tcx>
Sourcetype NestedFilter = All
type NestedFilter = All
Sourcefn maybe_tcx(&mut self) -> Self::MaybeTyCtxt
fn maybe_tcx(&mut self) -> Self::MaybeTyCtxt
type NestedFilter is set to visit nested items, this method
must also be overridden to provide a map to retrieve nested items.Sourcefn visit_item(&mut self, item: &'tcx Item<'tcx>) -> Self::Result
fn visit_item(&mut self, item: &'tcx Item<'tcx>) -> Self::Result
visit_nested_item for details.type MaybeTyCtxt = <Self::NestedFilter as NestedFilter<'v>>::MaybeTyCtxt
fn visit_nested_item(&mut self, id: ItemId) -> Self::Result
fn visit_nested_item(&mut self, id: ItemId) -> Self::Result
Self::NestedFilter is nested_filter::None, this method does
nothing. You probably don’t want to override this method –
instead, override [Self::NestedFilter] or use the “shallow” or
“deep” visit patterns described at
[rustc_hir::intravisit]. The only reason to override
this method is if you want a nested pattern but cannot supply a
TyCtxt; see maybe_tcx for advice.fn visit_nested_trait_item(&mut self, id: TraitItemId) -> Self::Result
fn visit_nested_trait_item(&mut self, id: TraitItemId) -> Self::Result
visit_nested_item(), but for trait items. See
visit_nested_item() for advice on when to override this
method.fn visit_nested_impl_item(&mut self, id: ImplItemId) -> Self::Result
fn visit_nested_impl_item(&mut self, id: ImplItemId) -> Self::Result
visit_nested_item(), but for impl items. See
visit_nested_item() for advice on when to override this
method.fn visit_nested_foreign_item(&mut self, id: ForeignItemId) -> Self::Result
fn visit_nested_foreign_item(&mut self, id: ForeignItemId) -> Self::Result
visit_nested_item(), but for foreign items. See
visit_nested_item() for advice on when to override this
method.fn visit_nested_body(&mut self, id: BodyId) -> Self::Result
fn visit_nested_body(&mut self, id: BodyId) -> Self::Result
visit_nested_item, does nothing by default unless you override
Self::NestedFilter.fn visit_param(&mut self, param: &'v Param<'v>) -> Self::Result
fn visit_body(&mut self, b: &Body<'v>) -> Self::Result
fn visit_id(&mut self, _hir_id: HirId) -> Self::Result
fn visit_name(&mut self, _name: Symbol) -> Self::Result
fn visit_ident(&mut self, ident: Ident) -> Self::Result
fn visit_mod(&mut self, m: &'v Mod<'v>, _s: Span, _n: HirId) -> Self::Result
fn visit_foreign_item(&mut self, i: &'v ForeignItem<'v>) -> Self::Result
fn visit_local(&mut self, l: &'v LetStmt<'v>) -> Self::Result
fn visit_block(&mut self, b: &'v Block<'v>) -> Self::Result
fn visit_stmt(&mut self, s: &'v Stmt<'v>) -> Self::Result
fn visit_arm(&mut self, a: &'v Arm<'v>) -> Self::Result
fn visit_pat(&mut self, p: &'v Pat<'v>) -> Self::Result
fn visit_pat_field(&mut self, f: &'v PatField<'v>) -> Self::Result
fn visit_pat_expr(&mut self, expr: &'v PatExpr<'v>) -> Self::Result
fn visit_lit( &mut self, _hir_id: HirId, _lit: Spanned<LitKind>, _negated: bool, ) -> Self::Result
fn visit_anon_const(&mut self, c: &'v AnonConst) -> Self::Result
fn visit_inline_const(&mut self, c: &'v ConstBlock) -> Self::Result
fn visit_generic_arg(&mut self, generic_arg: &'v GenericArg<'v>) -> Self::Result
fn visit_ty(&mut self, t: &'v Ty<'v, AmbigArg>) -> Self::Result
fn visit_ty(&mut self, t: &'v Ty<'v, AmbigArg>) -> Self::Result
fn visit_const_arg(&mut self, c: &'v ConstArg<'v, AmbigArg>) -> Self::Result
fn visit_const_arg(&mut self, c: &'v ConstArg<'v, AmbigArg>) -> Self::Result
fn visit_infer( &mut self, inf_id: HirId, inf_span: Span, kind: InferKind<'v>, ) -> Self::Result
fn visit_lifetime(&mut self, lifetime: &'v Lifetime) -> Self::Result
fn visit_expr(&mut self, ex: &'v Expr<'v>) -> Self::Result
fn visit_expr_field(&mut self, field: &'v ExprField<'v>) -> Self::Result
fn visit_pattern_type_pattern(&mut self, p: &'v TyPat<'v>) -> Self::Result
fn visit_generic_param(&mut self, p: &'v GenericParam<'v>) -> Self::Result
fn visit_const_param_default( &mut self, _param: HirId, ct: &'v ConstArg<'v>, ) -> Self::Result
fn visit_generics(&mut self, g: &'v Generics<'v>) -> Self::Result
fn visit_where_predicate( &mut self, predicate: &'v WherePredicate<'v>, ) -> Self::Result
fn visit_fn_ret_ty(&mut self, ret_ty: &'v FnRetTy<'v>) -> Self::Result
fn visit_fn_decl(&mut self, fd: &'v FnDecl<'v>) -> Self::Result
fn visit_fn( &mut self, fk: FnKind<'v>, fd: &'v FnDecl<'v>, b: BodyId, _: Span, id: LocalDefId, ) -> Self::Result
fn visit_use( &mut self, path: &'v Path<'v, PerNS<Option<Res>>>, hir_id: HirId, ) -> Self::Result
fn visit_trait_item(&mut self, ti: &'v TraitItem<'v>) -> Self::Result
fn visit_trait_item_ref(&mut self, ii: &'v TraitItemId) -> Self::Result
fn visit_impl_item(&mut self, ii: &'v ImplItem<'v>) -> Self::Result
fn visit_foreign_item_ref(&mut self, ii: &'v ForeignItemId) -> Self::Result
fn visit_impl_item_ref(&mut self, ii: &'v ImplItemId) -> Self::Result
fn visit_trait_ref(&mut self, t: &'v TraitRef<'v>) -> Self::Result
fn visit_param_bound(&mut self, bounds: &'v GenericBound<'v>) -> Self::Result
fn visit_precise_capturing_arg( &mut self, arg: &'v PreciseCapturingArgKind<&'v Lifetime, PreciseCapturingNonLifetimeArg>, ) -> Self::Result
fn visit_poly_trait_ref(&mut self, t: &'v PolyTraitRef<'v>) -> Self::Result
fn visit_opaque_ty(&mut self, opaque: &'v OpaqueTy<'v>) -> Self::Result
fn visit_variant_data(&mut self, s: &'v VariantData<'v>) -> Self::Result
fn visit_field_def(&mut self, s: &'v FieldDef<'v>) -> Self::Result
fn visit_enum_def(&mut self, enum_definition: &'v EnumDef<'v>) -> Self::Result
fn visit_variant(&mut self, v: &'v Variant<'v>) -> Self::Result
fn visit_label(&mut self, label: &'v Label) -> Self::Result
fn visit_qpath( &mut self, qpath: &'v QPath<'v>, id: HirId, _span: Span, ) -> Self::Result
fn visit_path(&mut self, path: &Path<'v>, _id: HirId) -> Self::Result
fn visit_path_segment( &mut self, path_segment: &'v PathSegment<'v>, ) -> Self::Result
fn visit_generic_args( &mut self, generic_args: &'v GenericArgs<'v>, ) -> Self::Result
fn visit_assoc_item_constraint( &mut self, constraint: &'v AssocItemConstraint<'v>, ) -> Self::Result
fn visit_attribute(&mut self, _attr: &'v Attribute) -> Self::Result
fn visit_defaultness(&mut self, defaultness: &'v Defaultness) -> Self::Result
fn visit_inline_asm( &mut self, asm: &'v InlineAsm<'v>, id: HirId, ) -> Self::Result